==> bybit-java-api-1.0.8-sources.jar: com/bybit/api/client/domain/position/PositionDataRequest.java <==
package com.bybit.api.client.domain.position;

import com.bybit.api.client.domain.ProductType;
import com.bybit.api.client.domain.TradeOrderType;
import com.bybit.api.client.domain.TriggerBy;
import com.bybit.api.client.domain.trade.PositionIdx;
import lombok.Builder;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

@Getter
@Setter
@Builder
@ToString
public class PositionDataRequest {
    private ProductType category;
    private String symbol;
    private String baseCoin;
    private String settleCoin;
    private String buyLeverage;
    private String sellLeverage;
    private Integer riskId;
    private PositionIdx positionIdx;
    private String takeProfit;
    private String stopLoss;
    private String trailingStop;
    private TriggerBy tpTriggerBy;
    private TriggerBy slTriggerBy;
    private String activePrice;
    private String tpSize;
    private String slSize;
    private String tpLimitPrice;
    private String slLimitPrice;
    private TradeOrderType tpOrderType;
    private TradeOrderType slOrderType;
    private AutoAddMargin autoAddMargin;
    private String margin;
    private String orderId;
    private String orderLinkId;
    private Long startTime;
    private Long endTime;
    private ExecType execType;
    private TpslMode tpslMode;
    private MarginMode tradeMode; // 0: cross margin. 1: isolated margin
    private PositionMode positionMode; // Position mode. 0: Merged Single. 3: Both Sides
    private Integer limit;
    private String cursor;
}

==> bybit-java-api-1.1.1-sources.jar: com/bybit/api/client/domain/position/PositionDataRequest.java <==
package com.bybit.api.client.domain.position;

import com.bybit.api.client.domain.CategoryType;
import com.bybit.api.client.domain.TradeOrderType;
import com.bybit.api.client.domain.TriggerBy;
import com.bybit.api.client.domain.trade.PositionIdx;
import lombok.Builder;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

@Getter
@Setter
@Builder
@ToString
public class PositionDataRequest {
    private CategoryType category;
    private String symbol;
    private String baseCoin;
    private String settleCoin;
    private String buyLeverage;
    private String sellLeverage;
    private Integer riskId;
    private PositionIdx positionIdx;
    private String takeProfit;
    private String stopLoss;
    private String trailingStop;
    private TriggerBy tpTriggerBy;
    private TriggerBy slTriggerBy;
    private String activePrice;
    private String tpSize;
    private String slSize;
    private String tpLimitPrice;
    private String slLimitPrice;
    private TradeOrderType tpOrderType;
    private TradeOrderType slOrderType;
    private AutoAddMargin autoAddMargin;
    private String margin;
    private String orderId;
    private String orderLinkId;
    private Long startTime;
    private Long endTime;
    private ExecType execType;
    private TpslMode tpslMode;
    private MarginMode tradeMode; // 0: cross margin. 1: isolated margin
    private PositionMode positionMode; // Position mode. 0: Merged Single. 3: Both Sides
    private Integer limit;
    private String cursor;
}
